package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.AdmOpAlarm;
import com.ruoyi.ems.service.IAdmOpAlarmService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 能源设施告警Controller
 *
 * @author ruoyi
 * @date 2024-08-26
 */
@RestController
@RequestMapping("/ems/alarm-info")
@Api(value = "AdmOpAlarmController", description = "能源设施告警")
public class AdmOpAlarmController extends BaseController {
    @Autowired
    private IAdmOpAlarmService opAlarmService;

    /**
     * 查询能源设施告警列表
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdmOpAlarm admOpAlarm) {
        startPage();
        List<AdmOpAlarm> list = opAlarmService.selectAdmOpAlarmList(admOpAlarm);
        return getDataTable(list);
    }

    /**
     * 导出能源设施告警列表
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:export')")
    @Log(title = "能源设施告警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmOpAlarm admOpAlarm) {
        List<AdmOpAlarm> list = opAlarmService.selectAdmOpAlarmList(admOpAlarm);
        ExcelUtil<AdmOpAlarm> util = new ExcelUtil<>(AdmOpAlarm.class);
        util.exportExcel(response, list, "能源设施告警数据");
    }

    /**
     * 获取能源设施告警详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(opAlarmService.selectAdmOpAlarmById(id));
    }

    /**
     * 新增能源设施告警
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:add')")
    @Log(title = "能源设施告警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmOpAlarm admOpAlarm) {
        return toAjax(opAlarmService.insertAdmOpAlarm(admOpAlarm));
    }

    /**
     * 修改能源设施告警
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:edit')")
    @Log(title = "能源设施告警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmOpAlarm admOpAlarm) {
        return toAjax(opAlarmService.updateAdmOpAlarm(admOpAlarm));
    }

    /**
     * 删除能源设施告警
     */
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:remove')")
    @Log(title = "能源设施告警", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(opAlarmService.deleteAdmOpAlarmByIds(ids));
    }

    @GetMapping("/alarm/type/index")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qryAlarmTypeIndex(@RequestParam("areaCode") String areaCode,
        @RequestParam("startRecTime") String startTime, @RequestParam("endRecTime") String endTime) {
        return success(opAlarmService.qryAlarmTypeIndex(areaCode, startTime, endTime));
    }

    @GetMapping("/alarm/type/index/day")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qryAlarmTypeIndexDay(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexDay(areaCode));
    }

    @GetMapping("/alarm/type/index/month")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qryAlarmTypeIndexMonth(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexMonth(areaCode));
    }

    @GetMapping("/alarm/type/index/year")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qryAlarmTypeIndexYear(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qryAlarmTypeIndexYear(areaCode));
    }

    @GetMapping("/subsys/index/day")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qrySubSysIndexDay(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qrySubSysIndexDay(areaCode));
    }

    @GetMapping("/subsys/index/month")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qrySubSysIndexMonth(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qrySubSysIndexMonth(areaCode));
    }

    @GetMapping("/subsys/index/year")
    @PreAuthorize("@ss.hasPermi('ems:alarm-info:query')")
    public AjaxResult qrySubSysIndexYear(@RequestParam("areaCode") String areaCode) {
        return success(opAlarmService.qrySubSysIndexYear(areaCode));
    }
}
