package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.ElecConsumeForecast;
import com.ruoyi.ems.service.IElecConsumeForecastService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电力消耗预测Controller
 *
 * @author ruoyi
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/ems/forecastConsume")
@Api(value = "ElecExpendForecastController", description = "电力消耗预测数据访问接口")
public class ElecConsumeForecastController extends BaseController
{
    @Autowired
    private IElecConsumeForecastService elecExpendForecastService;

    /**
     * 查询电力消耗预测列表
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:list')")
    @GetMapping("/list")
    public TableDataInfo list(ElecConsumeForecast forecast)
    {
        startPage();
        List<ElecConsumeForecast> list = elecExpendForecastService.selectForecastList(forecast);
        return getDataTable(list);
    }

    /**
     * 导出电力消耗预测列表
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:export')")
    @Log(title = "电力消耗预测", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecConsumeForecast forecast)
    {
        List<ElecConsumeForecast> list = elecExpendForecastService.selectForecastList(forecast);
        ExcelUtil<ElecConsumeForecast> util = new ExcelUtil<ElecConsumeForecast>(ElecConsumeForecast.class);
        util.exportExcel(response, list, "电力消耗预测数据");
    }

    /**
     * 获取电力消耗预测详细信息
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(elecExpendForecastService.selectForecastById(id));
    }

    /**
     * 新增电力消耗预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:add')")
    @Log(title = "电力消耗预测", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecConsumeForecast forecast)
    {
        return toAjax(elecExpendForecastService.insertForecast(forecast));
    }

    /**
     * 修改电力消耗预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:edit')")
    @Log(title = "电力消耗预测", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecConsumeForecast forecast)
    {
        return toAjax(elecExpendForecastService.updateForecast(forecast));
    }

    /**
     * 删除电力消耗预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:consume:remove')")
    @Log(title = "电力消耗预测", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(elecExpendForecastService.deleteForecastByIds(ids));
    }
}
