package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.ElecProdForecast;
import com.ruoyi.ems.service.IElecProdForecastService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电力产能预测Controller
 *
 * @author ruoyi
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/ems/predictionProd")
@Api(value = "ElecProdForecastController", description = "电力产能预测数据接口")
public class ElecProdForecastController extends BaseController
{
    @Autowired
    private IElecProdForecastService elecProdForecastService;

    /**
     * 查询电力产能预测列表
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:list')")
    @GetMapping("/list")
    public TableDataInfo list(ElecProdForecast elecProdForecast)
    {
        startPage();
        List<ElecProdForecast> list = elecProdForecastService.selectElecProdForecastList(elecProdForecast);
        return getDataTable(list);
    }

    /**
     * 导出电力产能预测列表
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:export')")
    @Log(title = "电力产能预测", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecProdForecast elecProdForecast)
    {
        List<ElecProdForecast> list = elecProdForecastService.selectElecProdForecastList(elecProdForecast);
        ExcelUtil<ElecProdForecast> util = new ExcelUtil<ElecProdForecast>(ElecProdForecast.class);
        util.exportExcel(response, list, "电力产能预测数据");
    }

    /**
     * 获取电力产能预测详细信息
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(elecProdForecastService.selectElecProdForecastById(id));
    }

    /**
     * 新增电力产能预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:add')")
    @Log(title = "电力产能预测", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecProdForecast elecProdForecast)
    {
        return toAjax(elecProdForecastService.insertElecProdForecast(elecProdForecast));
    }

    /**
     * 修改电力产能预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:edit')")
    @Log(title = "电力产能预测", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecProdForecast elecProdForecast)
    {
        return toAjax(elecProdForecastService.updateElecProdForecast(elecProdForecast));
    }

    /**
     * 删除电力产能预测
     */
    @PreAuthorize("@ss.hasPermi('prediction:prod:remove')")
    @Log(title = "电力产能预测", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(elecProdForecastService.deleteElecProdForecastByIds(ids));
    }
}
