package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.WaterMeterH;
import com.ruoyi.ems.model.QueryMeter;
import com.ruoyi.ems.service.IWaterMeterHService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 用水计量-小时Controller
 *
 * @author ruoyi
 * @date 2024-12-03
 */
@RestController
@RequestMapping("/ems/waterMeterH")
@Api(value = "WaterMeterHController", description = "用水计量-小时")
public class WaterMeterHController extends BaseController {
    @Autowired
    private IWaterMeterHService waterMeterHService;

    /**
     * 查询用水计量-小时列表
     */
    @PreAuthorize("@ss.hasPermi('ems:waterMeterH:list')")
    @GetMapping("/list1")
    public TableDataInfo list(QueryMeter queryMeter) {
        startPage();
        List<WaterMeterH> list = waterMeterHService.selectWaterMeterHList(queryMeter);
        return getDataTable(list);
    }

    /**
     * 导出用水计量-小时列表
     */
    @PreAuthorize("@ss.hasPermi('ems:waterMeterH:export')")
    @Log(title = "用水计量-小时", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QueryMeter queryMeter) {
        List<WaterMeterH> list = waterMeterHService.selectWaterMeterHList(queryMeter);
        ExcelUtil<WaterMeterH> util = new ExcelUtil<WaterMeterH>(WaterMeterH.class);
        util.exportExcel(response, list, "用水计量-小时数据");
    }

    /**
     * 新增用水计量-小时
     */
    @PreAuthorize("@ss.hasPermi('ems:waterMeterH:add')")
    @Log(title = "用水计量-小时", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WaterMeterH waterMeterH) {
        return toAjax(waterMeterHService.insertWaterMeterH(waterMeterH));
    }

    /**
     * 修改用水计量-小时
     */
    @PreAuthorize("@ss.hasPermi('ems:waterMeterH:edit')")
    @Log(title = "用水计量-小时", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WaterMeterH waterMeterH) {
        return toAjax(waterMeterHService.updateWaterMeterH(waterMeterH));
    }

    /**
     * 删除用水计量-小时
     */
    @PreAuthorize("@ss.hasPermi('ems:waterMeterH:remove')")
    @Log(title = "用水计量-小时", businessType = BusinessType.DELETE)
    @DeleteMapping("/delByDate")
    public AjaxResult remove(@RequestParam(name = "date") String date) {
        return toAjax(waterMeterHService.deleteWaterMeterHByDate(date));
    }
}
