package com.ruoyi.ems.controller;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.ElecPgSupplyH;
import com.ruoyi.ems.model.QueryMeter;
import com.ruoyi.ems.service.IElecPgSupplyHService;
import com.ruoyi.ems.service.IElecPvSupplyHService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电网供应计量-小时Controller
 *
 * @author ruoyi
 * @date 2024-08-09
 */
@RestController
@RequestMapping("/pg/supply/hour")
@Api(value = "ElecPgSupplyHController", description = "电网供应计量")
public class ElecPgSupplyHController extends BaseController {
    @Autowired
    private IElecPgSupplyHService pgSupplyHService;

    @Autowired
    private IElecPvSupplyHService pvSupplyHService;

    /**
     * 查询电网供应计量-小时列表
     */
    @RequiresPermissions("power-mgr:pg:list")
    @GetMapping("/list")
    public TableDataInfo list(ElecPgSupplyH admEmsPgSupplyH) {
        startPage();
        List<ElecPgSupplyH> list = pgSupplyHService.selectPgSupplyHList(admEmsPgSupplyH);
        return getDataTable(list);
    }

    /**
     * 查询电网供应计量-小时列表
     */
    @RequiresPermissions("power-mgr:pg:list")
    @GetMapping("/listByDate")
    public AjaxResult listByDate(QueryMeter queryMeter) {
        List<ElecPgSupplyH> list = pgSupplyHService.selectPgSupplyH(queryMeter);
        return success(list);
    }

    /**
     * 导出电网供应计量-小时列表
     */
    @RequiresPermissions("power-mgr:pg:export")
    @Log(title = "电网供应计量-小时", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElecPgSupplyH admEmsPgSupplyH) {
        List<ElecPgSupplyH> list = pgSupplyHService.selectPgSupplyHList(admEmsPgSupplyH);
        ExcelUtil<ElecPgSupplyH> util = new ExcelUtil<ElecPgSupplyH>(ElecPgSupplyH.class);
        util.exportExcel(response, list, "电网供应计量-小时数据");
    }

    /**
     * 获取电网供应计量-小时详细信息
     */
    @RequiresPermissions("power-mgr:pg:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(pgSupplyHService.selectPgSupplyHById(id));
    }

    @GetMapping(value = "/summery/h")
    public AjaxResult getSummeryByH() {
        return success(pgSupplyHService.selectSupplyByH());
    }

    @GetMapping(value = "/summery/this/day")
    public AjaxResult getSummeryByThisDay() {
        return success(pgSupplyHService.selectSupplyByDay());
    }

    /**
     * 新增电网供应计量-小时
     */
    @RequiresPermissions("power-mgr:pg:add")
    @Log(title = "电网供应计量-小时", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElecPgSupplyH admEmsPgSupplyH) {
        return toAjax(pgSupplyHService.insertPgSupplyH(admEmsPgSupplyH));
    }

    /**
     * 修改电网供应计量-小时
     */
    @RequiresPermissions("power-mgr:pg:edit")
    @Log(title = "电网供应计量-小时", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElecPgSupplyH admEmsPgSupplyH) {
        return toAjax(pgSupplyHService.updatePgSupplyH(admEmsPgSupplyH));
    }

    /**
     * 删除电网供应计量-小时
     */
    @RequiresPermissions("power-mgr:pg:remove")
    @Log(title = "电网供应计量-小时", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(pgSupplyHService.deletePgSupplyHByIds(ids));
    }


    @GetMapping(value = "/total/pv")
    public AjaxResult calPvByDateRange(QueryMeter param) {
        return success(pvSupplyHService.calPvByDateRange(param));
    }

    @GetMapping(value = "/day/pv")
    public AjaxResult calDayPvRange(QueryMeter param) {
        return success(pvSupplyHService.calDayPvRange(param));
    }

    @GetMapping(value = "/hour/pv")
    public AjaxResult calHourPvRange(QueryMeter param) {
        return success(pvSupplyHService.calHourPvRange(param));
    }

    @GetMapping(value = "/month/pv")
    public AjaxResult calMonthPvByDateRange(QueryMeter param) {
        return success(pvSupplyHService.calMonthPvByDateRange(param));
    }

    @GetMapping(value = "/month/pg")
    public AjaxResult calMonthSupplyByH(ElecPgSupplyH param) {
        return success(pgSupplyHService.calMonthSupplyByH(param));
    }
}
