package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsDevice;
import com.ruoyi.ems.model.QueryDevice;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 能源设备Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
@Mapper
public interface EmsDeviceMapper {
    /**
     * 查询能源设备
     *
     * @param id 能源设备主键
     * @return 能源设备
     */
    EmsDevice selectEmsDeviceById(Long id);

    /**
     * 查询能源设备
     *
     * @param code 能源设备编码
     * @return 能源设备
     */
    EmsDevice selectDeviceByCode(String code);

    /**
     * 查询能源设备
     *
     * @param code 能源设备编码
     * @return 能源设备
     */
    EmsDevice selectDetailByCode(String code);

    /**
     * 查询能源设备列表
     *
     * @param emsDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectDeviceList(QueryDevice emsDevice);

    /**
     * 查询能源设备列表
     *
     * @param emsDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectByFlowRel(QueryDevice emsDevice);

    /**
     * 查询能源设备列表
     *
     * @param emsDevice 能源设备
     * @return 能源设备集合
     */
    List<EmsDevice> selectDetailList(QueryDevice emsDevice);

    /**
     * 根据区域树递归查询设备
     *
     * @param queryDevice 条件
     * @return 设备列表
     */
    List<EmsDevice> selectByAreaTree(QueryDevice queryDevice);

    /**
     * 新增能源设备
     *
     * @param emsDevice 能源设备
     * @return 结果
     */
    int insertEmsDevice(EmsDevice emsDevice);

    /**
     * 修改能源设备
     *
     * @param emsDevice 能源设备
     * @return 结果
     */
    int updateEmsDevice(EmsDevice emsDevice);

    /**
     * 删除能源设备
     *
     * @param id 能源设备主键
     * @return 结果
     */
    int deleteEmsDeviceById(Long id);

    /**
     * 批量删除能源设备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteEmsDeviceByIds(Long[] ids);

    List<Map<String, Object>> cntDeviceStatus(@Param("areaCode") String areaCode);

    List<Map<String, Object>> calcDeviceOnlineSummary(@Param("areaCode") String areaCode);


    Map<String, Object> cntTotalDevice(@Param("areaCode") String areaCode);
}
