package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.EmsObjEvent;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 能源对象事件Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-23
 */
public interface EmsObjEventMapper {
    /**
     * 查询能源对象事件
     *
     * @param id 能源对象事件主键
     * @return 能源对象事件
     */
    EmsObjEvent selectObjEventById(Long id);

    /**
     * 查询能源对象事件列表
     *
     * @param objEvent 能源对象事件
     * @return 能源对象事件集合
     */
    List<EmsObjEvent> selectObjEventList(EmsObjEvent objEvent);

    /**
     * 根据modelCode查询能源对象事件列表
     *
     * @param modelCode 设备模型代码
     * @return 能源对象能力集合
     */
    List<EmsObjEvent> selectByModelCode(@Param("modelCode") String modelCode);

    /**
     * 新增能源对象事件
     *
     * @param objEvent 能源对象事件
     * @return 结果
     */
    int insertObjEvent(EmsObjEvent objEvent);

    /**
     * 批量新增能源对象事件
     *
     * @param list 能源对象事件
     * @return 结果
     */
    int insertBatch(List<EmsObjEvent> list);

    /**
     * 修改能源对象事件
     *
     * @param objEvent 能源对象事件
     * @return 结果
     */
    int updateObjEvent(EmsObjEvent objEvent);

    /**
     * 删除能源对象事件
     *
     * @param id 能源对象事件主键
     * @return 结果
     */
    int deleteObjEventById(Long id);

    /**
     * 根据modelCode删除能源对象事件
     *
     * @param modelCode 设备模型代码
     * @return 结果
     */
    int deleteByModelCode(@Param("modelCode") String modelCode);

    /**
     * 批量删除能源对象事件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteObjEventByIds(Long[] ids);
}
