package com.ruoyi.ems.service.impl;

import com.ruoyi.ems.domain.EmsDevice;
import com.ruoyi.ems.domain.EmsObjAttr;
import com.ruoyi.ems.domain.EmsObjAttrDto;
import com.ruoyi.ems.domain.EmsObjAttrEnum;
import com.ruoyi.ems.enums.DevObjType;
import com.ruoyi.ems.mapper.EmsObjAttrMapper;
import com.ruoyi.ems.service.IEmsDeviceService;
import com.ruoyi.ems.service.IEmsFacsService;
import com.ruoyi.ems.service.IEmsObjAttrEnumService;
import com.ruoyi.ems.service.IEmsObjAttrService;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 能源对象属性Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-23
 */
@Service
public class EmsObjAttrServiceImpl implements IEmsObjAttrService {
    @Autowired
    private EmsObjAttrMapper objAttrMapper;

    @Autowired
    private IEmsObjAttrEnumService enumService;

    @Autowired
    private IEmsDeviceService deviceService;

    @Autowired
    private IEmsFacsService facsService;

    /**
     * 查询能源对象属性
     *
     * @param id 能源对象属性主键
     * @return 能源对象属性
     */
    @Override
    public EmsObjAttr selectObjAttrById(Long id) {
        EmsObjAttr objAttr = objAttrMapper.selectObjAttrById(id);

        if (null != objAttr) {
            List<EmsObjAttrEnum> valueEnums = enumService.getObjAttrEnumList(objAttr.getModelCode(),
                objAttr.getAttrKey());
            objAttr.setValueEnums(valueEnums);
        }

        return objAttr;
    }

    /**
     * 查询能源对象属性列表
     *
     * @param objAttr 能源对象属性
     * @return 能源对象属性
     */
    @Override
    public List<EmsObjAttr> selectObjAttrList(EmsObjAttr objAttr) {
        List<EmsObjAttr> list = objAttrMapper.selectObjAttrList(objAttr);

        if (CollectionUtils.isNotEmpty(list)) {
            List<EmsObjAttrEnum> valueEnums = enumService.getObjAttrEnumList(objAttr.getModelCode(), null);
            Map<String, List<EmsObjAttrEnum>> enumMap = valueEnums.stream()
                .collect(Collectors.groupingBy(EmsObjAttrEnum::getAttrKey, Collectors.toList()));

            for (EmsObjAttr obj : list) {
                if (enumMap.containsKey(obj.getAttrKey())) {
                    obj.setValueEnums(enumMap.get(obj.getAttrKey()));
                }
            }
        }

        return list;
    }

    @Override
    public List<EmsObjAttr> selectByModelCode(String modelCode) {
        List<EmsObjAttr> list = objAttrMapper.selectByModelCode(modelCode);

        if (CollectionUtils.isNotEmpty(list)) {
            List<EmsObjAttrEnum> valueEnums = enumService.getObjAttrEnumList(modelCode, null);
            Map<String, List<EmsObjAttrEnum>> enumMap = valueEnums.stream()
                .collect(Collectors.groupingBy(EmsObjAttrEnum::getAttrKey, Collectors.toList()));

            for (EmsObjAttr obj : list) {
                if (enumMap.containsKey(obj.getAttrKey())) {
                    obj.setValueEnums(enumMap.get(obj.getAttrKey()));
                }
            }
        }

        return list;
    }

    @Override
    public List<EmsObjAttrDto> selectObjAttrItem(Integer objType, String objCode) {
        List<EmsObjAttrDto> ret = null;

        // 获取对象模型代码
        String modeCode = getModeCode(objType, objCode);

        if (StringUtils.isNotEmpty(modeCode)) {
            ret = objAttrMapper.selectObjAttrDto(modeCode, objType, objCode);
        }

        return ret;
    }

    /**
     * 新增能源对象属性
     *
     * @param objAttr 能源对象属性
     * @return 结果
     */
    @Override
    public int insertObjAttr(EmsObjAttr objAttr) {
        int cnt = objAttrMapper.insertObjAttr(objAttr);
        mergeAttrEnum(objAttr);

        return cnt;
    }

    @Override
    public int insertBatch(List<EmsObjAttr> list) {
        int cnt = 0;

        if (CollectionUtils.isNotEmpty(list)) {
            cnt = objAttrMapper.insertBatch(list);

            for (EmsObjAttr objAttr : list) {
                mergeAttrEnum(objAttr);
            }
        }

        return cnt;
    }

    /**
     * 修改能源对象属性
     *
     * @param objAttr 能源对象属性
     * @return 结果
     */
    @Override
    public int updateObjAttr(EmsObjAttr objAttr) {
        int cnt = objAttrMapper.updateObjAttr(objAttr);
        mergeAttrEnum(objAttr);
        return cnt;
    }

    /**
     * 批量删除能源对象属性
     *
     * @param ids 需要删除的能源对象属性主键
     * @return 结果
     */
    @Override
    public int deleteObjAttrByIds(Long[] ids) {
        for (Long id : ids) {
            EmsObjAttr objAttr = objAttrMapper.selectObjAttrById(id);

            if (null != objAttr) {
                enumService.deleteByModelCode(objAttr.getModelCode());
            }
        }

        return objAttrMapper.deleteObjAttrByIds(ids);
    }

    /**
     * 删除能源对象属性信息
     *
     * @param id 能源对象属性主键
     * @return 结果
     */
    @Override
    public int deleteObjAttrById(Long id) {
        int cnt = 0;
        EmsObjAttr objAttr = objAttrMapper.selectObjAttrById(id);

        if (null != objAttr) {
            cnt = objAttrMapper.deleteObjAttrById(id);
            enumService.deleteByModelCode(objAttr.getModelCode());
        }

        return cnt;
    }

    @Override
    public int deleteByModelCode(String modelCode) {
        int cnt = objAttrMapper.deleteByModelCode(modelCode);
        enumService.deleteByModelCode(modelCode);
        return cnt;
    }

    private void mergeAttrEnum(EmsObjAttr objAttr) {
        if (StringUtils.equals(objAttr.getAttrValueType(), "Enum")) {
            enumService.deleteByModelCode(objAttr.getModelCode());

            if (CollectionUtils.isNotEmpty(objAttr.getValueEnums())) {
                enumService.addObjAttrEnumBatch(objAttr.getValueEnums());
            }
        }
    }

    private String getModeCode(Integer objType, String objCode) {
        String modeCode = null;

        if (objType == DevObjType.DEVC.getCode()) {
            EmsDevice device = deviceService.selectByCode(objCode);
            modeCode = null != device ? device.getDeviceModel() : null;
        }

        return modeCode;
    }
}
